CacheEntry class

A cache entry: body + ETag + last-fetched time.

Constructors

CacheEntry({required List<int> body, required String? etag, required DateTime fetchedAt})
Creates a CacheEntry.
const

Properties

body List<int>
The cached body (as a List<int> so it works for both JSON and binary).
final
etag String?
The ETag (or null if the response didn't have one).
final
fetchedAt DateTime
When this entry was fetched.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited