EnumerableQueryProvider class

The default in-memory provider. Singleton.

Use EnumerableQueryProvider.instance to obtain it.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createQuery<T>(Expr expression) IQueryable<T>
Creates a new IQueryable from a root expression.
override
execute<TResult>(Expr expression) → TResult
Executes a scalar expression (e.g. Count, Sum).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance EnumerableQueryProvider
final