HttpDelete class

Inheritance

Constructors

HttpDelete([String path = '', Map<String, String> headers = const <String, String>{}])
const

Properties

hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
Headers extra para este método (se combinan con los de clase).
finalinherited
path String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited