MemberAccessExpr class

Inheritance
Available extensions

Constructors

MemberAccessExpr(Expr target, String name)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target Expr
final

Methods

accept<R>(ExprVisitor<R> v) → R
External visitor for providers (SQL translator, codegen emitter, …).
override
eval(Map<String, Object?> ctx) Object?
In-memory evaluation against a context.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited