executor property
The executor the migration body uses to run SQL statements. Bound to the in-flight transaction.
Implementation
final MigrationExecutor executor;
The executor the migration body uses to run SQL statements. Bound to the in-flight transaction.
final MigrationExecutor executor;