MutationCommand class

An INSERT / UPDATE / DELETE command about to be executed. Same pattern as QueryCommand: interceptors can transform SQL and binds.

Constructors

MutationCommand({required String sql, required List<Object?> binds, required String table, required String operation, Object? entity})
const

Properties

binds List<Object?>
final
entity Object?
The entity being mutated (for INSERT and UPDATE — null for bulk operations that don't carry a single entity).
final
hashCode int
The hash code for this object.
no setterinherited
operation String
'INSERT', 'UPDATE', or 'DELETE'.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sql String
final
table String
final

Methods

copyWith({String? sql, List<Object?>? binds, String? table, String? operation, Object? entity}) MutationCommand
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited