Parameter class sealed

Anotaciones a nivel de parámetro. Determinan de dónde sale el valor.

  • Body: cuerpo de la petición (se serializa a JSON con d_serializer).
  • Query: query string ?name=value.
  • Path: segmento de ruta {name}.
  • Header: header HTTP.
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited