sqliteType property

String sqliteType
final

Canonical SQLite type for the Dart type (INTEGER, TEXT, REAL, …). Captured at snapshot time so a later change to the type mapper is visible in the diff.

Implementation

final String sqliteType;