SchemaOperationType enum

: type of a SchemaDiff. Maps 1:1 to a SQL DDL operation (with two exceptions: modifyColumn has no direct SQL in SQLite, and renameColumn is a heuristic that suggests a possible rename).

Inheritance
Available extensions

Values

createTable → const SchemaOperationType
dropTable → const SchemaOperationType
addColumn → const SchemaOperationType
dropColumn → const SchemaOperationType
modifyColumn → const SchemaOperationType
createIndex → const SchemaOperationType
dropIndex → const SchemaOperationType
renameColumn → const SchemaOperationType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SchemaOperationType>
A constant List of the values in this enum, in order of their declaration.