TernaryExpr class

.e: a ternary cond ? then: else.

Inheritance
Available extensions

Constructors

TernaryExpr(Expr cond, Expr thenBranch, Expr elseBranch)
const

Properties

cond Expr
final
elseBranch Expr
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thenBranch Expr
final

Methods

accept<R>(ExprVisitor<R> v) → R
External visitor for providers (SQL translator, codegen emitter, …).
override
eval(Map<String, Object?> ctx) Object?
In-memory evaluation against a context.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited