FibonacciBackoffRetryPolicy class
Fibonacci-spaced delays: 1, 1, 2, 3, 5, 8, 13, ... * unitDelay.
- Implemented types
Constructors
- FibonacciBackoffRetryPolicy({Duration unitDelay = const Duration(seconds: 1), int maxAttempts = 5})
-
Creates a FibonacciBackoffRetryPolicy
with
unitDelay(default 1s) andmaxAttempts(default 5).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxAttempts → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unitDelay → Duration
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRetry(
{required int attempt, required Object error, StackTrace? stackTrace}) → RetryDecision -
Decide whether to retry after
attemptfailures.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited