GroupByExpr class
A GROUP BY clause with optional post-aggregation
filter (HAVING). In SQL this is
SELECT key[, element] FROM source GROUP BY key [HAVING pred].
- Inheritance
- Available extensions
Constructors
- GroupByExpr({required Expr keySelector, Expr? elementSelector, Expr? havingPredicate})
-
const
Properties
- elementSelector → Expr?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- havingPredicate → Expr?
-
final
- keySelector → Expr
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
accept<
R> (ExprVisitor< R> v) → R -
External visitor for providers (SQL translator, codegen emitter, …).
override
-
eval(
Map< String, Object?> ctx) → Object? -
In-memory evaluation against a context.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited