HttpPackageClient class
Implementación por defecto de HttpClient basada en package:http.
- Implemented types
Constructors
-
HttpPackageClient({Client? client, List<
RestInterceptor> interceptors = const <RestInterceptor>[]})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
interceptors
→ List<
RestInterceptor> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< void> -
Permite liberar recursos. Por defecto es no-op.
override
-
execute(
RestRequest request, {required Decoder decoder, CancelToken? cancelToken}) → Future< RestResponse> -
Ejecuta la petición y devuelve una respuesta "cruda" (todavía
sin decodificar el body a un tipo concreto). El RestClient
se encarga de aplicar el Decoder.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited