IncludeMany<T, R> class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
inverseFkColumn
→ String
-
The FK column on the related table
(e.g.
'book_id'). Each row where
relatedTable.<this> = T.id is included.
final
-
navigationName
→ String
-
The navigation property name on
T
(e.g. 'author', 'sales').
finalinherited
-
relatedMeta
→ EntityMeta
-
The EntityMeta of the related table. Used
by the runtime to materialise the related rows
via
EntityMeta.fromRow.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
override