IncludeRelation<T, R> class
sealed
A relation to be eager-loaded by
DbSet<T>.findById(id, joins: [...]).
IncludeRelation is sealed: only the
documented subtypes (IncludeOne for @BelongsTo
and IncludeMany for @HasMany) can be
instantiated.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
The navigation property name on
T(e.g.'author','sales').final -
The EntityMeta of the related table. Used
by the runtime to materialise the related rows
via
EntityMeta.fromRow.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited