ManualSyncTrigger class
Manual trigger that exposes SignalSyncTrigger.fire so the user can integrate it with their own event sources (e.g. a custom network-reconnect listener, an app-lifecycle observer, etc.). Same as SignalSyncTrigger but documented as "manual" to make the intent clearer.
- Inheritance
-
- Object
- SignalSyncTrigger
- ManualSyncTrigger
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fire(
) → void -
Fire the trigger (e.g. on pull-to-refresh).
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
Future< void> onTrigger()) → void -
Starts the trigger. Calls
onTriggerwhenever the trigger fires. The user is expected to chain onTrigger toctx.syncAsync(...).inherited -
stop(
) → void -
Stops the trigger. Called from
DbContext.stopSyncTriggers (or
automatically on context dispose).
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited