RestResponse<T> class
Constructors
-
RestResponse({required int statusCode, String? reasonPhrase, required Map<
String, String> headers, T? body, required String rawBody, required RestRequest request}) -
const
Properties
- body → T?
-
final
- hasBody → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
final
- isSuccess → bool
-
no setter
- rawBody → String
-
final
- reasonPhrase → String?
-
final
- request → RestRequest
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited